| Title: | Data Package using Korean Standard Dictionary |
|---|---|
| Description: | stdictkr is a client package that uses the API provided by 'the Korean standard dictionary' <https://stdict.korean.go.kr/openapi/openApiInfo.do>. You can also directly download a dictionary and use it as a tibble data type. |
| Authors: | Chanyub Park [aut, cre] (ORCID: <https://orcid.org/0000-0001-6474-2570>) |
| Maintainer: | Chanyub Park <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.0.9000 |
| Built: | 2026-06-02 10:09:04 UTC |
| Source: | https://github.com/mrchypark/stdictkr |
Remove API Key on stdict
std_auth_remove()std_auth_remove()
stdict korean api can use search api
std_search(query, start = 1, count = 10)std_search(query, start = 1, count = 10)
query |
query for search |
start |
query result of start |
count |
count of result number |
a tibble
stdict korean api can use view api
std_view(query, method = "word_info")std_view(query, method = "word_info")
query |
query for view |
method |
method. default is "word_info" |